Examples
########
This section contains a collection of examples that demonstrate how to use the IQM Benchmarks package to perform various benchmarks. The first run all experiments in the package, and the rest are specific examples of different benchmarking protocols.

.. toctree::
   :maxdepth: 1

   example_experiment_all
   example_clifford_rb
   example_interleaved_rb
   example_eplg
   example_mirror_rb
   example_graphstate
   example_gst
   example_quantum_volume
   example_ghz
   example_qscore
   example_coherence
   example_clops